<?php

namespace Locations\NotificationSchedule\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Locations\NotificationSchedule\Http\Requests\NotificationScheduleRequest;
use Locations\NotificationSchedule\Interfaces\NotificationScheduleRepositoryInterface;
use Locations\NotificationSchedule\Models\NotificationSchedule;
use Locations\NotificationSchedule\Forms\NotificationSchedule as Form;

/**
 * APIController  class for notification_schedule.
 */
class NotificationScheduleAPIController extends BaseController
{

    /**
     * Initialize notification_schedule resource controller.
     *
     * @param type NotificationScheduleRepositoryInterface $notification_schedule
     *
     * @return null
     */
    public function __construct(NotificationScheduleRepositoryInterface $notification_schedule)
    {
        parent::__construct();
        $this->repository = $notification_schedule;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Locations\NotificationSchedule\Repositories\Criteria\NotificationScheduleResourceCriteria::class);
    }

    /**
     * Display a list of notification_schedule.
     *
     * @return Response
     */
    public function index(NotificationScheduleRequest $request)
    {
        return $this->repository
            ->setPresenter(\Locations\NotificationSchedule\Repositories\Presenter\NotificationSchedulePresenter::class)
            ->paginate();
    }

    /**
     * Display notification_schedule.
     *
     * @param Request $request
     * @param Model   $notification_schedule
     *
     * @return Response
     */
    public function show(NotificationScheduleRequest $request, NotificationSchedule $notification_schedule)
    {
        return $notification_schedule->setPresenter(\Locations\NotificationSchedule\Repositories\Presenter\NotificationScheduleListPresenter::class);
        ;
    }

    /**
     * Create new notification_schedule.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(NotificationScheduleRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('notification_schedule::notification_schedule.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('notification_schedule/notification_schedule/' . $notification_schedule->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('notification_schedule/notification_schedule');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the notification_schedule.
     *
     * @param Request $request
     * @param Model   $notification_schedule
     *
     * @return Response
     */
    public function update(NotificationScheduleRequest $request, NotificationSchedule $notification_schedule)
    {
        try {
            $data = $request->all();

            $notification_schedule->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('notification_schedule::notification_schedule.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('notification_schedule/notification_schedule/' . $notification_schedule->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('notification_schedule/notification_schedule/' . $notification_schedule->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the notification_schedule.
     *
     * @param Model   $notification_schedule
     *
     * @return Response
     */
    public function destroy(NotificationScheduleRequest $request, NotificationSchedule $notification_schedule)
    {
        try {
            $notification_schedule->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('notification_schedule::notification_schedule.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('notification_schedule/notification_schedule/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('notification_schedule/notification_schedule/' . $notification_schedule->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
