<?php

namespace Locations\NotificationSchedule\Policies;

use Litepie\User\Contracts\UserPolicy;
use Locations\NotificationSchedule\Models\NotificationDeliveredList;

class NotificationDeliveredListPolicy
{

    /**
     * Determine if the given user can view the notification_delivered_list.
     *
     * @param UserPolicy $user
     * @param NotificationDeliveredList $notification_delivered_list
     *
     * @return bool
     */
    public function view(UserPolicy $user, NotificationDeliveredList $notification_delivered_list)
    {
        if ($user->canDo('notification_schedule.notification_delivered_list.view') && $user->isAdmin()) {
            return true;
        }

        return $notification_delivered_list->user_id == user_id() && $notification_delivered_list->user_type == user_type();
    }

    /**
     * Determine if the given user can create a notification_delivered_list.
     *
     * @param UserPolicy $user
     * @param NotificationDeliveredList $notification_delivered_list
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('notification_schedule.notification_delivered_list.create');
    }

    /**
     * Determine if the given user can update the given notification_delivered_list.
     *
     * @param UserPolicy $user
     * @param NotificationDeliveredList $notification_delivered_list
     *
     * @return bool
     */
    public function update(UserPolicy $user, NotificationDeliveredList $notification_delivered_list)
    {
        if ($user->canDo('notification_schedule.notification_delivered_list.edit') && $user->isAdmin()) {
            return true;
        }

        return $notification_delivered_list->user_id == user_id() && $notification_delivered_list->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given notification_delivered_list.
     *
     * @param UserPolicy $user
     * @param NotificationDeliveredList $notification_delivered_list
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, NotificationDeliveredList $notification_delivered_list)
    {
        return $notification_delivered_list->user_id == user_id() && $notification_delivered_list->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given notification_delivered_list.
     *
     * @param UserPolicy $user
     * @param NotificationDeliveredList $notification_delivered_list
     *
     * @return bool
     */
    public function verify(UserPolicy $user, NotificationDeliveredList $notification_delivered_list)
    {
        if ($user->canDo('notification_schedule.notification_delivered_list.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given notification_delivered_list.
     *
     * @param UserPolicy $user
     * @param NotificationDeliveredList $notification_delivered_list
     *
     * @return bool
     */
    public function approve(UserPolicy $user, NotificationDeliveredList $notification_delivered_list)
    {
        if ($user->canDo('notification_schedule.notification_delivered_list.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
