<?php

namespace Locations\NotificationSchedule\Policies;

use Litepie\User\Contracts\UserPolicy;
use Locations\NotificationSchedule\Models\NotificationSchedule;

class NotificationSchedulePolicy
{

    /**
     * Determine if the given user can view the notification_schedule.
     *
     * @param UserPolicy $user
     * @param NotificationSchedule $notification_schedule
     *
     * @return bool
     */
    public function view(UserPolicy $user, NotificationSchedule $notification_schedule)
    {
        if ($user->canDo('notification_schedule.notification_schedule.view') && $user->isAdmin()) {
            return true;
        }

        return $notification_schedule->user_id == user_id() && $notification_schedule->user_type == user_type();
    }

    /**
     * Determine if the given user can create a notification_schedule.
     *
     * @param UserPolicy $user
     * @param NotificationSchedule $notification_schedule
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('notification_schedule.notification_schedule.create');
    }

    /**
     * Determine if the given user can update the given notification_schedule.
     *
     * @param UserPolicy $user
     * @param NotificationSchedule $notification_schedule
     *
     * @return bool
     */
    public function update(UserPolicy $user, NotificationSchedule $notification_schedule)
    {
        if ($user->canDo('notification_schedule.notification_schedule.edit') && $user->isAdmin()) {
            return true;
        }

        return $notification_schedule->user_id == user_id() && $notification_schedule->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given notification_schedule.
     *
     * @param UserPolicy $user
     * @param NotificationSchedule $notification_schedule
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, NotificationSchedule $notification_schedule)
    {
        return $notification_schedule->user_id == user_id() && $notification_schedule->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given notification_schedule.
     *
     * @param UserPolicy $user
     * @param NotificationSchedule $notification_schedule
     *
     * @return bool
     */
    public function verify(UserPolicy $user, NotificationSchedule $notification_schedule)
    {
        if ($user->canDo('notification_schedule.notification_schedule.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given notification_schedule.
     *
     * @param UserPolicy $user
     * @param NotificationSchedule $notification_schedule
     *
     * @return bool
     */
    public function approve(UserPolicy $user, NotificationSchedule $notification_schedule)
    {
        if ($user->canDo('notification_schedule.notification_schedule.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
