<?php

namespace Locations\NotificationSchedule\Providers;

use Illuminate\Support\ServiceProvider;

class NotificationScheduleServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'notification_schedule');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'notification_schedule');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerNotificationSchedule();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerNotificationSchedule()
    {
        $this->app->bind('notification_schedule', function($app) {
            return new NotificationSchedule($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('NotificationSchedule', 'Lavalite\NotificationSchedule\Facades\NotificationSchedule');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('locations.notification_schedule', function ($app) {
            return $this->app->make('Locations\NotificationSchedule\NotificationSchedule');
        });

        // Bind NotificationSchedule to repository
        $this->app->bind(
            'Locations\NotificationSchedule\Interfaces\NotificationScheduleRepositoryInterface',
            \Locations\NotificationSchedule\Repositories\Eloquent\NotificationScheduleRepository::class
        );        // Bind NotificationDeliveredList to repository
        $this->app->bind(
            'Locations\NotificationSchedule\Interfaces\NotificationDeliveredListRepositoryInterface',
            \Locations\NotificationSchedule\Repositories\Eloquent\NotificationDeliveredListRepository::class
        );

        $this->app->register(\Locations\NotificationSchedule\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Locations\NotificationSchedule\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and notification_schedule's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'locations.notification_schedule'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeNotificationSchedule::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['locations.notification_schedule'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('locations/notification_schedule.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/notification_schedule')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/notification_schedule')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
