<?php

namespace Locations\NotificationSchedule\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Locations\NotificationSchedule\Models\NotificationSchedule;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Locations\NotificationSchedule\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/notification_schedule/notification_schedule/*')) {
            Route::bind('notification_schedule', function ($notification_schedule) {
                $notification_schedulerepo = $this->app->make('Locations\NotificationSchedule\Interfaces\NotificationScheduleRepositoryInterface');
                return $notification_schedulerepo->findorNew($notification_schedule);
            });
        }
        if (Request::is('*/notification_schedule/notification_delivered_list/*')) {
            Route::bind('notification_delivered_list', function ($notification_delivered_list) {
                $notification_delivered_listrepo = $this->app->make('Locations\NotificationSchedule\Interfaces\NotificationDeliveredListRepositoryInterface');
                return $notification_delivered_listrepo->findorNew($notification_delivered_list);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
